@@ -90,6 +90,12 @@ expectType<commander.Command>(program.hook('preAction', (thisCommand, actionComm
   expectType<commander.Command>(thisCommand);
   expectType<commander.Command>(actionCommand);
 }));
+expectType<commander.Command>(program.hook('preSubcommand', () => {}));
+expectType<commander.Command>(program.hook('preSubcommand', (thisCommand, subcommand) => {
+  // implicit parameter types
+  expectType<commander.Command>(thisCommand);
+  expectType<commander.Command>(subcommand);
+}));
 
 // action
 expectType<commander.Command>(program.action(() => {}));
@@ -239,6 +245,10 @@ expectType<commander.Command>(program.description('my description'));
 expectType<string>(program.description());
 expectType<commander.Command>(program.description('my description of command with arg foo', { foo: 'foo description' })); // deprecated
 
+// summary
+expectType<commander.Command>(program.summary('my summary'));
+expectType<string>(program.summary());
+
 // alias
 expectType<commander.Command>(program.alias('my alias'));
 expectType<string>(program.alias());
@@ -418,6 +428,9 @@ expectType<commander.Option>(baseOption.choices(['a', 'b'] as const));
 expectType<commander.Option>(baseOption.conflicts('a'));
 expectType<commander.Option>(baseOption.conflicts(['a', 'b']));
 
+// implies
+expectType<commander.Option>(baseOption.implies({ option: 'VALUE', colour: false }));
+
 // name
 expectType<string>(baseOption.name());
 
